/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.atlas;


/**
 * <p>IdentifiableATLASElement is an abstraction for elements that can be
 * identified in ATLAS. These elements bear a unique Id that can be used to
 * identify them via, for instance, a reference.</p>
 *
 * <p>Note, however, that being identifiable does not imply that the identified
 * element can be referenced in a different context. Only these elements that
 * also implement the ReusableATLASElement interface can be reused.</p>
 *
 * @version $Revision: 1.2 $
 * @author Christophe Laprun
 *
 * @see ReusableATLASElement
 */
public interface IdentifiableATLASElement extends ATLASElement {
  /**
   * Returns the identifier associated with this IdentifiableATLASElement.
   *
   * @return the identifier associated with this IdentifiableATLASElement
   */
  Id getId();

  /*#Id lnkId;*/
}

