/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.atlas;


/**
 * MetadataHolder specifies the behavior expected from elements
 * manipulating Metadata.
 *
 * @version $Revision: 1.2 $
 * @author Christophe Laprun
 *
 * @see Metadata
 */
public interface MetadataHolder {
  /**
   * Retrieves the Metadata associated with this MetadataHolder.
   *
   * @return the Metadata associated with this MetadataHolder
   */
  Metadata getMetadata();

  /**
   * Assigns a new value to this MetadataHolder's Metadata.
   *
   * @param metadata the new Metadata to be assigned
   *
   * @return <code>true</code> if the operation was successful,
   * <code>false</code> otherwise
   */
  boolean setMetadata(Metadata metadata);

  /**
   * Determines if this MetadataHolder contains any Metadata.
   *
   * @return <code>true</code> if this MetadataHolder contains any Metadata,
   * <code>false</code> otherwise
   */
  boolean hasMetadata();
}

