/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.atlas.util;

import java.util.Comparator;

/**
 * Interface specifying the behavior for classes which subordinate elements are
 * sortable.
 *
 * @author Christophe Laprun
 * @version $Revision: 1.2 $
 *
 * @since 2.0 beta 2
 */
public interface Sortable {
  /**
   * Sorts the elements contained in this Sortable using their natural order.
   *
   * @throws ClassCastException if the list contains elements that are not
   * mutually comparable (for example, strings and integers) or if the elements
   */
  void sort();

  /**
   * Sorts the elements contained in this Sortable using the orderind provided
   * by the specified Comparator.
   *
   * @param comparator the Comparator to use to sort the elements contained in
   *        this Sortable
   *
   * @throws ClassCastException if the list contains elements that are not
   * mutually comparable (for example, strings and integers) or if the elements
   */
  void sort(Comparator comparator);
}
