/*
 * MAIA
 * Meta-Annotation Infrastructure for ATLAS
 * Author: Chris Laprun
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.maia;

import gov.nist.atlas.type.ATLASType;
import gov.nist.atlas.type.AnnotationType;
import gov.nist.atlas.type.ChildrenType;
import gov.nist.atlas.util.ATLASImplementation;
import org.dom4j.Element;

import java.util.Iterator;

class AnnotationTypeBuilder extends ATLASTypeBuilder {
  AnnotationTypeBuilder(ATLASImplementation implementation, ATLASTypeBuilderFactory builderFactory, MAIAScheme scheme) {
    super(implementation, builderFactory, scheme);
  }

  ATLASType build(Element e) {
    AnnotationType type = factory.createEmptyAnnotationType(null, getNameOrRef(e), scheme);
    scheme.registerType(type);

    // build RegionType
    buildSimpleFor(e.element(MAIALoader.REGION), builderFactory.getRegionTypeBuilder(scheme), type);

    // build ContentType
    buildSimpleFor(e.element(MAIALoader.CONTENT), builderFactory.getContentTypeBuilder(scheme), type);

    // build ChildrenType
    Element e2;
    Iterator children = e.elementIterator(MAIALoader.CHILDREN);
    while (children.hasNext()) {
      e2 = (Element) children.next();
      ChildrenType childrenType = (ChildrenType) buildSimpleFor(
          e2, builderFactory.getChildrenTypeBuilder(scheme), type);
      ATLASType consolidatedType = scheme.getAnnotationType(getNameOrRef(e2));
      childrenType.setConsolidatedElementType(consolidatedType);
      if (e2.attributeValue("isOrderMeaningful") != null)
        childrenType.setOrderMeaningful(true);
    }

    // set Region defining Children (if any)
    String role;
    e2 = e.element(MAIALoader.REGION_DEFINED_AS);
    if (e2 != null) {
      role = e2.attributeValue(MAIALoader.CHILDREN_ROLE);
      type.setRegionDefiningChildren(scheme.getRegionType(getNameOrRef(e2)), role);
    }

    // set Content defining Children (if any)
    e2 = e.element(MAIALoader.CONTENT_DEFINED_AS);
    if (e2 != null) {
      role = e2.attributeValue(MAIALoader.CHILDREN_ROLE);
      type.setContentDefiningChildren(scheme.getContentType(getNameOrRef(e2)), role);
    }

    return type;
  }
}
